<?php 

$lang['module_name'] = 'Налаштування меню сайту';

$lang['new_item'] = 'пункт меню';

$lang['field_list'] = array(
    'translate_name' => 'Назва пункту',
    'parent_id' => 'Належить',
    'href' => 'Сторінка',
    'active_class' => 'Клас активного ел.',
    'template' => 'Шаблон',
    'view_order' => 'Порядок відображення',
    'active' => 'Відображать',
    'name' => 'Назва',
    'id_site_menu_type' => 'Меню'
);
$lang['active'] = 'Так';
$lang['no_active'] = 'Ні';