<?php 

$lang['module_name'] = 'Настройка меню сайта';

$lang['new_item'] = 'пункт меню';

$lang['field_list'] = array(
    'translate_name' => 'Название пункта',
    'parent_id' => 'Принадлежит',
    'href' => 'Страница',
    'active_class' => 'Класс активного эл.',
    'template' => 'Шаблон',
    'view_order' => 'Порядок отображения',
    'active' => 'Отображать',
    'name' => 'Название',
    'id_site_menu_type' => 'Меню'
);
$lang['active'] = 'Да';
$lang['no_active'] = 'Нет';